@@ -67,7 +67,7 @@ class Main(object):
         parser.add_argument("-p", "--bind-port", dest="bind_port",
                             type=int,
                             default=10809,
-                            help="bind address (default: 10811)")
+                            help="bind address (default: 10809)")
 
         parser.add_argument("-c", "--cache-limit", dest="cache_limit",
                             type=int,
@@ -158,7 +158,7 @@ class Main(object):
                                              object_size,
                                              objects,
                                              Cache(int(self.args.cache_limit*1024**2 / object_size)),
-                                             values['read-only'],
+                                             values['read-only'].lower() in ('1', 'yes', 'true', 'on'),
                                             )
 
         addr = (self.args.bind_address, self.args.bind_port)
